﻿Import-Module ActiveDirectory 
 
$EnableRDGW = $true
$RDGW = "rdgw.$env:USERDNSDOMAIN"

$domain = $env:userdomain 
$OutputFile = "$home\$env:USERDNSDOMAIN.rdg" 

$template = @' 
<?xml version="1.0" encoding="utf-8"?> 
<RDCMan schemaVersion="1"> 
    <version>2.2</version> 
    <file> 
    <credentialsProfiles>
      <credentialsProfile inherit="None">
        <profileName scope="Local">NAME</profileName>
        <userName>USERNAME</userName>
        <password></password>
        <domain>DOMAIN</domain>
      </credentialsProfile>
    </credentialsProfiles>
    <properties>
      <expanded>True</expanded>
      <name></name>
    </properties>
    <logonCredentials inherit="None">
    <profileName scope="File">None</profileName>
    </logonCredentials>
    <gatewaySettings inherit="None">
      <enabled>False</enabled>
      <hostName></hostName>
      <logonMethod>NTLM</logonMethod>
      <localBypass>False</localBypass>
      <credSharing>True</credSharing>
      <profileName scope="File">None</profileName>
    </gatewaySettings>
    <remoteDesktop inherit="None">
      <sameSizeAsClientArea>True</sameSizeAsClientArea>
      <fullScreen>False</fullScreen>
      <colorDepth>24</colorDepth>
    </remoteDesktop>
    <localResources inherit="None">
      <audioRedirection>Client</audioRedirection>
      <audioRedirectionQuality>Dynamic</audioRedirectionQuality>
      <audioCaptureRedirection>DoNotRecord</audioCaptureRedirection>
      <keyboardHook>FullScreenClient</keyboardHook>
      <redirectClipboard>True</redirectClipboard>
      <redirectDrives>False</redirectDrives>
      <redirectDrivesList />
      <redirectPrinters>False</redirectPrinters>
      <redirectPorts>False</redirectPorts>
      <redirectSmartCards>False</redirectSmartCards>
      <redirectPnpDevices>False</redirectPnpDevices>
    </localResources>
    <securitySettings inherit="None">
      <authentication>None</authentication>
    </securitySettings>
    <encryptionSettings inherit="FromParent">
    </encryptionSettings>
        <server> 
             <displayName></displayName> 
             <name></name> 
             <comment /> 
             <logonCredentials inherit="FromParent" /> 
             <connectionSettings inherit="FromParent" /> 
             <gatewaySettings inherit="FromParent" /> 
             <remoteDesktop inherit="FromParent" /> 
             <localResources inherit="FromParent" /> 
             <securitySettings inherit="FromParent" /> 
             <displaySettings inherit="FromParent" /> 
            </server> 
    </file> 
</RDCMan> 
'@ 
 
$template | Out-File $home\RDCMan-template.xml -encoding UTF8 
 
$xml = New-Object xml 
$xml.Load("$home\RDCMan-template.xml") 
 
$file = (@($xml.RDCMan.file.properties)[0]).Clone() 
$file.name = "$env:USERDNSDOMAIN" 
$xml.RDCMan.file.properties | Where-Object { $_.Name -eq "" } | ForEach-Object  { [void]$xml.RDCMan.file.ReplaceChild($file,$_) } 

if ($EnableRDGW -eq $true) {
    $xml.RDCMan.file.gatewaySettings.hostName = $RDGW
    $xml.RDCMan.file.gatewaySettings.enabled = "True"
    }

$xml.RDCMan.file.credentialsProfiles.credentialsProfile.profileName.'#text' = "$env:USERDOMAIN\$env:USERNAME"
$xml.RDCMan.file.credentialsProfiles.credentialsProfile.userName = "$env:USERNAME"
$xml.RDCMan.file.credentialsProfiles.credentialsProfile.domain = "$env:USERDOMAIN"
$xml.RDCMan.file.logonCredentials.profileName.'#text' = "$env:USERDOMAIN\$env:USERNAME"
$xml.RDCMan.file.gatewaySettings.profileName.'#text' = "$env:USERDOMAIN\$env:USERNAME"

$server = (@($xml.RDCMan.file.server)[0]).Clone() 
get-adcomputer -LDAPFilter "(&(objectCategory=computer)(operatingSystem=Windows Server*)(!serviceprincipalname=*MSClusterVirtualServer*)(!(userAccountControl:1.2.840.113556.1.4.803:=2)))" -Property name,dnshostname,description | sort-object Name | select name,dnshostname,description | 
ForEach-Object { 
$server = $server.clone()     
$server.DisplayName = $_.Name     
$server.Name = $_.DNSHostName 
if ($_.Description -ne $Null) { 
    $server.comment = $_.Description 
    } 
else { 
  $server.comment = "" 
  } 

$xml.RDCMan.file.AppendChild($server) > $null} 
 
$xml.RDCMan.file.server | Where-Object { $_.Name -eq "" } | ForEach-Object  { [void]$xml.RDCMan.file.RemoveChild($_) } 

$xml.Save($OutputFile) 
 
Remove-Item $home\RDCMan-template.xml -Force

Write-Output "$OutputFile Created" 
